Stalker — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- Stalker v0.1.1.a9 documentation »

# Stalker

## About

Stalker is a Production Asset Management (ProdAM) System designed specifically for Animation and VFX Studios and licensed under BSD License.

Features:
  - Platform independent
  - Flexible design
  - Designed for animation and vfx studios
  - Default installation handles nearly all the asset management needs of an animation and vfx studio
  - Customisable with configuration scripts
  - Customisable object model (Stalker Object Model - SOM)
  - Integrated messaging system
  - Integrated production planing and tracking tools
  - PySide user interfaces
  - Can be used with any kind of databases supported by SQLAlchemy
  - Can be connected to all the major 3d animation packages like Maya, Houdini, Nuke, XSI, Vue, Blender etc. and any application that has a Python API
  - Can work as a stand-alone application
Stalker is build over these other OpenSource projects:
  - Python
  - SQLAlchemy
  - Jinja2
  - Beaker
  - PySide
  - Pyramid

## Source

The latest development version is available in Google Project page of Stalker or can be directly cloned with the following command if you already have mercurial installed:

    hg clone https://stalker.googlecode.com/hg/ stalker

## Table of Contents

- Installation
- Tutorial
- Design
- How To Contribute
- Stalker Development Roadmap
- Stalker Changes

### Summary

`stalker.db` | Database module of Stalker.
`stalker.db.engine` |
`stalker.db.mapper` | this is the default mapper to map the default models to the default tables
`stalker.db.metadata` | A collection of Tables and their associated schema constructs.
`stalker.db.mixin` | contains helper classes which helps mixed in classes table and mapper setups
`stalker.db.mixin.ReferenceMixinDB` | A helper class for ReferenceMixin table and mapper setup.
`stalker.db.mixin.StatusMixinDB` | A helper class for StatusMixin table and mapper setup.
`stalker.db.mixin.ScheduleMixinDB` | A helper class for ScheduleMixin table and mapper setup.
`stalker.db.tables` |
`stalker.db.query` |
`stalker.db.session` |
`stalker.db.setup` | Utillty function that helps to connect the system to the given database.
`stalker.core.errors` | Errors for the system.
`stalker.core.errors.CircularDependencyError` | Raised when there is cirular dependencies within Tasks
`stalker.core.errors.LoginError` | Raised when the login information is not correct or not correlate with the data in the database.
`stalker.core.errors.DBError` | Raised when there is no database and a database related action has been placed.
`stalker.core.mixins` | This module contains the Mixins (ta taaa).
`stalker.core.mixins.ReferenceMixin` | Adds reference capabilities to the mixed in class.
`stalker.core.mixins.ScheduleMixin` | Adds schedule info to the mixed in class.
`stalker.core.mixins.StatusMixin` | Adds statusabilities to the object.
`stalker.core.mixins.TaskMixin` | Gives the abilitiy to connect to a list of taks to the mixed in object.
`stalker.core.models` |
`stalker.core.models.Asset` | The Asset class is the whole idea behind Stalker.
`stalker.core.models.Booking` | Holds information about the time spend on a specific task by a specific user.
`stalker.core.models.Comment` | User reviews and comments about other entities.
`stalker.core.models.Department` | The departments that forms the studio itself.
`stalker.core.models.FilenameTemplate` | Holds templates for filename conventions.
`stalker.core.models.Entity` | Another base data class that adds tags and notes to the attributes list.
`stalker.core.models.ImageFormat` | Common image formats for the projects.
`stalker.core.models.Link` | Holds data about external links.
`stalker.core.models.Message` | The base of the messaging system in Stalker
`stalker.core.models.Note` | To leave notes about the connected node
`stalker.core.models.PermissionGroup` | Manages permission in the system.
`stalker.core.models.Project` | All the information about a Project in Stalker is hold in this class.
`stalker.core.models.Repository` | Repository is a class to hold repository server data.
`stalker.core.models.Sequence` | Stores data about Sequences.
`stalker.core.models.Shot` | Manages Shot related data.
`stalker.core.models.SimpleEntity` | The base class of all the others
`stalker.core.models.Status` | Defins object statutes.
`stalker.core.models.StatusList` | Type specific list of `Status` instances.
`stalker.core.models.Structure` | A structure object is the place to hold data about how the physical files are arranged in the `Repository`.
`stalker.core.models.Tag` | the tag class
`stalker.core.models.Task` | Manages Task related data.
`stalker.core.models.Type` | Everything can have a type.
`stalker.core.models.User` | The user class is designed to hold data about a User in the system.
`stalker.core.models.Version` | The connection to the filesystem.
`stalker.ext.auth` | This is the authentication system of Stalker. Uses Beaker for the session
`stalker.ext.auth.authenticate` | Authenticates the given username and password, returns a
`stalker.ext.auth.check_password` | Checks the given raw password.
`stalker.ext.auth.create_session` | Creates the beaker.session object.
`stalker.ext.auth.login` | Persists the user_id in a session.
`stalker.ext.auth.login_required` | a decorator that implements login functionality to any function or
`stalker.ext.auth.logout` | removes the current session
`stalker.ext.auth.permission_required` | a decorator that implements permission checking to any function or
`stalker.ext.auth.set_password` | Returns an encrypted version of the given password.
`stalker.ext.validatedList` |
`stalker.ext.validatedList.ValidatedList` | A list variant which accepts only one type of element.
`stalker.utils.path_to_exec` | This is a utiliy function which converts full class or function paths

### Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Stalker v0.1.1.a9 documentation »